<?php

namespace Drupal\entity_reference_preview\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Entity Reference Preview settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_reference_preview_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['entity_reference_preview.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['draft_indicator'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Draft Indicator'),
      '#description' => $this->t('When enabled, users with enough permissions will be able to navigate the site and see a blue dot over the referenced entities that have ongoing drafts.'),
      '#default_value' => $this->config('entity_reference_preview.settings')->get('enableDraftIndicator'),
    ];
    $form['attribution'] = [
      '#markup' => 'Icons made by <a href="https://www.flaticon.com/authors/freepik" title="Freepik">Freepik</a> from <a href="https://www.flaticon.com/" title="Flaticon"> www.flaticon.com</a>',
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('entity_reference_preview.settings')
      ->set('enableDraftIndicator', $form_state->getValue('draft_indicator'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
